@@ -51,7 +51,9 @@ class VariableOsAudio(Variable):
             audio = getValueFromCmdLine(CmdlineParams.Calculate,
                                         CmdlineParams.Audio)
 
-            if audio and audio == "pulseaudio":
+            if audio and audio == "alsa":
+                return "alsa"
+            else:
                 return "pulseaudio"
         return "alsa"
 
