@@ -427,8 +427,8 @@ class VariableClMigrateUserGroups(UserHelper, Variable):
     """
     type = 'choice-list-list'
     defaultGroupList = sorted(["users", "audio", "cdrom", "video",
-                        "cdrw", "usb", "plugdev", "games", "lp", "scanner",
-                        "uucp"])
+                        "cdrw", "usb", "plugdev", "games", "lp", "lpadmin",
+                        "scanner", "uucp"])
     default_value = "default"
 
     @classmethod
